@@ -2,14 +2,15 @@
 
 
 
-def print_lol(thelists,level):
+def print_lol(thelists,indent=False,level=0):
     """this function is running print the array"""
     for thelist in thelists:
         if isinstance(thelist, list):
-            print_lol(thelist,level+1)
+            print_lol(thelist,indent,level+1)
         else:
-            for tab_stop in range(level):
-                print("\t")
+            if indent:
+                for tab_stop in range(level):
+                    print('--')
             print(thelist)
     #function end
         
